pub struct ResearchingQuantity {
pub total_researching_quantity: Option<i32>,
pub researching_quantity_breakdown: Option<Vec<ResearchingQuantityEntry>>,
}Expand description
ResearchingQuantity : The number of misplaced or warehouse damaged units that are actively being confirmed at our fulfillment centers.
Fields
total_researching_quantity: Option<i32>The total number of units currently being researched in Amazon’s fulfillment network.
researching_quantity_breakdown: Option<Vec<ResearchingQuantityEntry>>A list of quantity details for items currently being researched.
Implementations
sourceimpl ResearchingQuantity
impl ResearchingQuantity
sourcepub fn new() -> ResearchingQuantity
pub fn new() -> ResearchingQuantity
The number of misplaced or warehouse damaged units that are actively being confirmed at our fulfillment centers.